
/****************************************************************************************************//**
 * @file     LSM303.h
 *
 * @brief    LSM303 configuration and communications Header File
 *
 * @version  V1
 * @date     30. November 2015
 *
 * @note     
 *           
 *
 * @par      Copyright (c) 2015, Token Logic Ltd.
 *           All rights reserved.
 *           
 *
 *******************************************************************************************************/

#ifndef LSM303_H
#define LSM303_H

#include "app_twi.h"


/** Device I2C addresses **/
#define LSM303_ADDRESS_ACCEL		(0x32U >> 1)         // 0011001x
#define LSM303_ADDRESS_MAG			(0x3CU >> 1)         // 0011110x

#define LSM303_REG_AUTO_INC		0x80	// Bitwise or and register with this to enable auto-increment

#define DEFAULT_FORCE_TRIGGER 9
				
/** Accelerometer control and data register enum **/
typedef enum{                                
	LSM303_ACC_CTRL_REG1_A         = 0x20U,   // 00000111   rw
	LSM303_ACC_CTRL_REG2_A         = 0x21U,   // 00000000   rw
	LSM303_ACC_CTRL_REG3_A         = 0x22U,   // 00000000   rw
	LSM303_ACC_CTRL_REG4_A         = 0x23U,   // 00000000   rw
	LSM303_ACC_CTRL_REG5_A         = 0x24U,   // 00000000   rw
	LSM303_ACC_CTRL_REG6_A         = 0x25U,   // 00000000   rw
	LSM303_ACC_REFERENCE_A         = 0x26U,   // 00000000   r
	LSM303_ACC_STATUS_REG_A        = 0x27U,   // 00000000   r
	LSM303_ACC_OUT_X_L_A           = 0x28U,
	LSM303_ACC_OUT_X_H_A           = 0x29U,
	LSM303_ACC_OUT_Y_L_A           = 0x2AU,
	LSM303_ACC_OUT_Y_H_A           = 0x2BU,
	LSM303_ACC_OUT_Z_L_A           = 0x2CU,
	LSM303_ACC_OUT_Z_H_A           = 0x2DU,
	LSM303_ACC_FIFO_CTRL_REG_A     = 0x2EU,
	LSM303_ACC_FIFO_SRC_REG_A      = 0x2FU,
	LSM303_ACC_INT1_CFG_A          = 0x30U,
	LSM303_ACC_INT1_SOURCE_A       = 0x31U,
	LSM303_ACC_INT1_THS_A          = 0x32U,
	LSM303_ACC_INT1_DURATION_A     = 0x33U,
	LSM303_ACC_INT2_CFG_A          = 0x34U,
	LSM303_ACC_INT2_SOURCE_A       = 0x35U,
	LSM303_ACC_INT2_THS_A          = 0x36U,
	LSM303_ACC_INT2_DURATION_A     = 0x37U,
	LSM303_ACC_CLICK_CFG_A         = 0x38U,
	LSM303_ACC_CLICK_SRC_A         = 0x39U,
	LSM303_ACC_CLICK_THS_A         = 0x3AU,
	LSM303_ACC_TIME_LIMIT_A        = 0x3BU,
	LSM303_ACC_TIME_LATENCY_A      = 0x3CU,
	LSM303_ACC_TIME_WINDOW_A       = 0x3DU
} LSM303AccRegs_t;

/* Accelerometer data rate */  
typedef enum{
	ODR_POWER_DOWN	= 0x00,
	ODR_1Hz			= 0x10,
	ODR_10Hz		= 0x20,
	ODR_25Hz		= 0x30,
	ODR_50Hz		= 0x40,
	ODR_100Hz		= 0x50,
	ODR_200Hz		= 0x60,
	ODR_400Hz		= 0x70,
	ODR_1344Hz		= 0x90
} LSM303AccODR_t;

/* Accelerometer axis enabling */  
typedef enum{
	Acc_X_EN		= 0x01,
	Acc_Y_EN		= 0x02,
	Acc_Z_EN		= 0x04,
	Acc_LP_EN	= 0x08
} LSM303AccAxisEnable_t;

/* Accelerometer interrupt configuration */  
typedef enum{
	Acc_AOI				= 0x80,
	Acc_6D				= 0x40,
	Acc_ZHI_EVT			= 0x20,
	Acc_ZLI_EVT			= 0x10,
	Acc_Z_EVT			= 0x30,
	Acc_YHI_EVT			= 0x08,
	Acc_YLI_EVT			= 0x04,
	Acc_Y_EVT			= 0x0C,
	Acc_XHI_EVT			= 0x02,
	Acc_XLI_EVT			= 0x01,
	Acc_X_EVT			= 0x03,
	Acc_ANY_AXIS_EVT	= 0x3F
	
} LSM303AccIntCfg_t;

/* Accelerometer interrupt source (READ ONLY) */ 
/* Must be read if Int1 latch is active */
typedef enum{
	Acc_INT_ACTIVE	= 0x40,
	Acc_ZHI			= 0x20,
	Acc_ZLO			= 0x10,
	Acc_YHI			= 0x08,
	Acc_YLO			= 0x04,
	Acc_XHI			= 0x02,
	Acc_XLO			= 0x01
} LSM303AccIntSrc_t;

// The MSB of INT1_DURATION_A and INT1_THS_A must be 0 for correct operation
// Bitwise and with this when writing a byte value to these 7-bit registers
#define SAFEMASK	0x7F

/////////////////////////////////

/** Magnetometer control and data registers **/
typedef enum{
  LSM303_MAG_CRA_REG_M   	= 0x00,
  LSM303_MAG_CRB_REG_M   	= 0x01,
  LSM303_MAG_MR_REG_M    	= 0x02,
  LSM303_MAG_OUT_X_H_M   	= 0x03,
  LSM303_MAG_OUT_X_L_M   	= 0x04,
  LSM303_MAG_OUT_Z_H_M   	= 0x05,
  LSM303_MAG_OUT_Z_L_M   	= 0x06,
  LSM303_MAG_OUT_Y_H_M   	= 0x07,
  LSM303_MAG_OUT_Y_L_M   	= 0x08,
  LSM303_MAG_SR_REG_Mg   	= 0x09,
  LSM303_MAG_IRA_REG_M   	= 0x0A,
  LSM303_MAG_IRB_REG_M   	= 0x0B,
  LSM303_MAG_IRC_REG_M   	= 0x0C,
  LSM303_MAG_TEMP_OUT_H_M	= 0x31,
  LSM303_MAG_TEMP_OUT_L_M	= 0x32
} LSM303MagRegs_t;

/** Magnetometer gain **/
typedef enum{
  LSM303_MAGGAIN_1_3		= 0x20,  // +/- 1.3
  LSM303_MAGGAIN_1_9		= 0x40,  // +/- 1.9
  LSM303_MAGGAIN_2_5		= 0x60,  // +/- 2.5
  LSM303_MAGGAIN_4_0		= 0x80,  // +/- 4.0
  LSM303_MAGGAIN_4_7		= 0xA0,  // +/- 4.7
  LSM303_MAGGAIN_5_6		= 0xC0,  // +/- 5.6
  LSM303_MAGGAIN_8_1		= 0xE0   // +/- 8.1
} LSM303MagCRB_t;

typedef enum{
	MAG_TEMP_EN 	= 0x80,
	MAG_ODR_7Hz		= 0x0C,
	MAG_ODR_15Hz	= 0x1C			// default
} LSM303MagCRA_t;

typedef enum{
	MAG_CONTINUOUS_CONV 	= 0x00,
	MAG_SINGLE_CONV			= 0x01,
	MAG_SLEEP_MODE			= 0x03	// default
} LSM303MagMR_t;

typedef enum{
	ACC	= LSM303_ADDRESS_ACCEL,
	MAG	= LSM303_ADDRESS_MAG
} LSM303Sensor_t;
/* 
				-- LSM303 data buffer -- 
+-----------------------------------------------------------------+
|	Index		|	Description					|	Note							|	
|-----------+--------------------------+--------------------------+
|	[0..5] 	|	X,Y,Z Acceleration 		|	LSB:MSB 12-bit	
|	[6..11] 	|	X,Y,Z Magnetism			|	MSB:LSB 12-bit	
|	[11..13]	|	Misc register storage	|		
+-----------+--------------------------+-------------------------*/
#define LSM303_BUFFER_SIZE  6
static uint8_t m_lsm303_acc_buffer[LSM303_BUFFER_SIZE];


static uint8_t const lsm303_acc_ctrl_reg = LSM303_REG_AUTO_INC | LSM303_ACC_CTRL_REG1_A;
static uint8_t const lsm303_mag_ctrl_reg = LSM303_REG_AUTO_INC | LSM303_MAG_MR_REG_M;
// first accelerometer data register
static uint8_t const lsm303_acc_first_reg = LSM303_REG_AUTO_INC | LSM303_ACC_OUT_X_L_A;
// first magnetometer data register
static uint8_t const lsm303_mag_first_reg = LSM303_REG_AUTO_INC | LSM303_MAG_OUT_X_H_M;


#define LSM303_READ(sensor_addr, p_reg_addr, p_buffer, byte_cnt) \
				APP_TWI_WRITE(sensor_addr, p_reg_addr, 1, APP_TWI_NO_STOP), \
				APP_TWI_READ (sensor_addr, p_buffer, byte_cnt, 0)

#define LSM303_ACC_REG_READ(p_buffer) \
				LSM303_READ(ACC, &lsm303_acc_ctrl_reg, p_buffer, 2)
				
#define LSM303_MAG_REG_READ(p_buffer) \
				LSM303_READ(MAG, &lsm303_mag_ctrl_reg, p_buffer, 1)

#define LSM303_ACC_XYZ_READ(p_buffer) \
				LSM303_READ(ACC, &lsm303_acc_first_reg, p_buffer, 6)
				
#define LSM303_MAG_XYZ_READ(p_buffer) \
				LSM303_READ(MAG, &lsm303_mag_first_reg, p_buffer, 6)

/** Global function prototypes **/


void LSM303_default_config(app_twi_t *m_twi);

void LSM303_get_register(LSM303Sensor_t sensor, app_twi_t *m_app_twi, uint8_t *m_register);

void LSM303_sleep(LSM303Sensor_t sensor);





#endif
