
/****************************************************************************************************//**
 * @file     LSM303.h
 *
 * @brief    LSM303 configuration and communications Header File
 *
 * @version  V1
 * @date     30. November 2015
 *
 * @note     
 *           
 *
 * @par      Copyright (c) 2015, Token Logic Ltd.
 *           All rights reserved.
 *           
 *
 *******************************************************************************************************/

#ifndef SHT21_H
#define SHT21_H

#include "app_twi.h"


/** Device I2C address **/
#define SHT21_ADDRESS			(0x80U >> 1)	// 0011001x
				
/** Sensor control and data register enum **/
typedef enum{
	SHT21_TRIG_T_MEASUREMENT_HM   	= 0xE3, // command trig. temp meas. hold master
	SHT21_TRIG_RH_MEASUREMENT_HM  	= 0xE5, // command trig. humidity meas. hold master
	SHT21_TRIG_T_MEASUREMENT_POLL 	= 0xF3, // command trig. temp meas. no hold master
	SHT21_TRIG_RH_MEASUREMENT_POLL	= 0xF5, // command trig. humidity meas. no hold master
	SHT21_USER_REG_W              	= 0xE6, // command writing user register
	SHT21_USER_REG_R              	= 0xE7, // command reading user register
	SHT21_SOFT_RESET              	= 0xFE  // command soft reset
}SHT21Command;

typedef enum {
  SHT21_RES_12_14BIT				= 0x00, // RH=12bit, T=14bit
  SHT21_RES_8_12BIT 				= 0x01, // RH= 8bit, T=12bit
  SHT21_RES_10_13BIT				= 0x80, // RH=10bit, T=13bit
  SHT21_RES_11_11BIT				= 0x81, // RH=11bit, T=11bit
  SHT21_RES_MASK    				= 0x81  // Mask for res. bits (7,0) in user reg.
}SHT21Resolution;

typedef enum {
  SHT21_EOB_ON  					= 0x40, // end of battery
  SHT21_EOB_MASK					= 0x40, // Mask for EOB bit(6) in user reg.
}SHT21Eob;

typedef enum {
  SHT21_HEATER_ON  				= 0x04, // heater on
  SHT21_HEATER_OFF 				= 0x00, // heater off
  SHT21_HEATER_MASK				= 0x04, // Mask for Heater bit(2) in user reg.
}etSHT2xHeater;

// measurement signal selection
typedef enum{
  HUMIDITY,
  TEMP
}SHT21MeasureType;

/* 
							-- SHT21 data buffer -- 
+-----------------------------------------------------------------+
|	Index		|	Description					|	Note							|	
|-----------+--------------------------+--------------------------+
|	[0..1] 	|	Relative humidity 		|	MSB:LSB left justified	|
|	[2..3] 	|	Temperature				|	MSB:LSB left justified	|
|	[4]	 	|	Configuration register 	|	Contains EoB notifier	|
+-----------+--------------------------+-------------------------*/
#define SHT21_BUFFER_SIZE  5
#define RH_START_INDEX  0
#define	T_START_INDEX	2
#define CFG_REG_INDEX	4
static uint8_t m_sht21_buffer[SHT21_BUFFER_SIZE];

static uint8_t const sht21_reg_read = SHT21_USER_REG_R;
static uint8_t const sht21_t_read 	= SHT21_TRIG_T_MEASUREMENT_HM;
static uint8_t const sht21_rh_read 	= SHT21_TRIG_RH_MEASUREMENT_HM;


#define SHT21_READ(p_reg_addr, p_buffer, byte_cnt) \
				APP_TWI_WRITE(SHT21_ADDRESS, p_reg_addr, 1, APP_TWI_NO_STOP), \
				APP_TWI_READ (SHT21_ADDRESS, p_buffer, byte_cnt, 0)
/*
#define SHT21_WRITE(p_reg_addr, p_buffer, byte_cnt) \
				APP_TWI_WRITE(LSM303_ADDRESS_ACCEL, p_reg_addr, 1, NULL, \
*/

#define SHT21_REG_READ(p_buffer) \
				SHT21_READ(&sht21_t_read, p_buffer, 1)

#define SHT21_T_READ(p_buffer) \
				SHT21_READ(&sht21_t_read, p_buffer, 2)

#define SHT21_RH_READ(p_buffer) \
				SHT21_READ(&sht21_rh_read, p_buffer, 2)

/** Global function prototypes **/

void SHT21_default_config(app_twi_t *m_app_twi, uint8_t *m_user_reg);
void SHT21_get_register(app_twi_t *m_app_twi, uint8_t *m_user_reg);




#endif
