/* Copyright (c) 2016 Token Zero Ltd
 * All rights reserved.
 * 
 */

#ifndef CORE_SERVICE_H__
#define CORE_SERVICE_H__

#include <stdint.h>
#include "ble.h"
#include "ble_srv_common.h"





#define BLE_UUID_CORE_BASE_UUID	     		  {{0xB3, 0x58, 0x55, 0x40, 0x50, 0x60, 0x11, 0xe3, \
												0x8f, 0x96, 0x08, 0x00, 0x00, 0x00, 0x9a, 0x66}}      /**< 128bit UUID base used for example. */

#define MULTILINK_PERIPHERAL_SERVICE_UUID  		0x9001                                   			  /**< Serrvice UUID over the 128-bit base used for the example. */
#define MULTILINK_PERIPHERAL_CHAR_UUID     		0x900A                                   			  /**< Characteristic UUID over the 128-bit base used for the example. */

												
												
#define BLE_UUID_CORE_SERVICE               	0x9001 // Just a random, but recognizable value

#define BLE_UUID_CONFIG_CHAR_UUID   			0xB50F // Just a random, but recognizable value
#define BLE_UUID_SAMPLERATE_CHAR_UUID     		0xB502 // Just a random, but recognizable value
#define BLE_UUID_TEMP_CHAR_UUID					0xB503
#define BLE_UUID_RH_CHAR_UUID					0x900A


/**
 * @brief This structure contains various status information for our service. 
 * It only holds one entry now, but will be populated with more items as we go.
 * The name is based on the naming convention used in Nordic's SDKs. 
 * 'ble indicates that it is a Bluetooth Low Energy relevant structure and 
 * os is short for Our Service). 
 */
typedef struct
{
	uint16_t					conn_handle;			/**< Handle of the current connection (as provided by the BLE stack, is BLE_CONN_HANDLE_INVALID if not in a connection).*/
    uint16_t    				service_handle;     	/**< Handle of Our Service (as provided by the BLE stack). */
	ble_gatts_char_handles_t	temp_handles;
	ble_gatts_char_handles_t	rh_handles;		
}ble_cs_t;




/**@brief Function for handling BLE Stack events related to our service and characteristic.
 *
 * @details Handles all events from the BLE stack of interest to Our Service.
 *
 * @param[in]   p_ble_evt  		Event received from the BLE stack.
 */
void ble_core_service_on_ble_evt(ble_evt_t * p_ble_evt);


/**@brief Function for initializing our new service.
 *
 * @param[in]   p_our_service       Pointer to Our Service structure.
 */
void core_service_init(void);





#endif  /* _ CORE_SERVICE_H__ */
