/* Copyright (c) Token Zero Ltd
 * All rights reserved.
 * 
 */

#ifndef HARDWARE_H__
#define HARDWARE_H__

#include <stdint.h>
#include "app_twi.h"
#include "board_tknRev1.h"


/* TWI instance */
//bak1

/**
 * @brief This structure contains various status information for our service. 
 * It only holds one entry now, but will be populated with more items as we go.
 * The name is based on the naming convention used in Nordic's SDKs. 
 * 'ble’ indicates that it is a Bluetooth Low Energy relevant structure and 
 * ‘os’ is short for Our Service). 
 */




/**@brief Function for handling BLE Stack events related to our service and characteristic.
 *
 * @details Handles all events from the BLE stack of interest to Our Service.
 *
 * @param[in]   p_our_service   Our Service structure.
 * @param[in]   p_ble_evt  		Event received from the BLE stack.
 */
 
 /**
 * @brief Function for hardware initialisation
 */
void hardware_init(void);

void transact_twi(app_twi_transaction_t const * p_transaction);

void adc_light_read(void);




/**@brief Function for initializing our new service.
 *
 * @param[in]   p_our_service       Pointer to Our Service structure.
 */


/**@brief Function for updating and sending new characteristic values
 *
 * @details The application calls this function whenever our timer_timeout_handler triggers
 *
 * @param[in]   p_our_service                     Our Service structure.
 * @param[in]   characteristic_value     New characteristic value.
 */




#endif  /* _ HARDWARE_H__ */
